@@ -32,7 +32,8 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     Examples
     --------
     >>> import numpy as np
-    >>> conaction.estimators.minkowski_deviation(np.arange(10))
+    >>> data = np.arange(10)
+    >>> minkowski_deviation(data)
     5.338539126015656
     '''
     result = x - np.mean(x)
@@ -55,7 +56,7 @@ def reflective_correlation(X: np.ndarray) -> np.float64:
 
     Returns
     -------
-    r : float
+    r : np.float64
         Reflective correlation coefficient score.
 
     References
@@ -95,7 +96,7 @@ def pearson_correlation(X: np.ndarray) -> np.float64:
 
     Returns
     -------
-    r : float
+    r : np.float64
         The calculated Pearson r correlation coefficient.
 
     References
@@ -125,7 +126,7 @@ def circular_correlation(X: np.ndarray) -> np.float64:
 
     Returns
     -------
-        r : float
+        r : np.float64
             Circular correlation coefficient.
 
     References
@@ -174,7 +175,7 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
 
     Returns
     -------
-        : float
+        : np.float64
             Spearman's correlation coefficient.
             
     References
@@ -192,22 +193,34 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
 
 # TODO: Implement
 def angular_disimilarity(X: np.ndarray) -> np.float64:
-    '''
-    .. warn: Not implemented yet.
-    Computes the n-ary angular disimilarity.
+    ''' 
+    Computes the multilinear angular disimilarity.
     When given an m x 2 data matrix, it is equivalent
     to the angular distance.
 
+    Parameters
+    ----------
+    X : array_like
+        m x n data matrix
+
+    Returns
+    -------
+    : np.float64
+        angular disimilarity
+
     References
     ----------
     .. [1] "Angular distance", https://en.wikipedia.org/wiki/Cosine_similarity#Angular_distance_and_similarity
     .. [2] "What is the exact and precise definition of an ANGLE?", https://math.stackexchange.com/questions/583066/what-is-the-exact-and-precise-definition-of-an-angle
     '''
+    return np.arccos(reflective_correlation(X)) / np.pi
 
 # TODO: Implement 
 def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
     '''
-    .. warning: Not implemented yet.
+    .. warning::
+        Not implemented yet.
+        
     This function calculates the multilinear correlation ratio of a
     collection of response variables given their classes. The
     classic Fisher's correlation ratio is a special case.
@@ -229,6 +242,7 @@ def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
     global_means = np.mean(X, axis=0)
     classes = set(y)
     partitions_X = [X[y == c] for c in classes]
+    
 
 def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float64:
     '''
@@ -245,8 +259,8 @@ def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float6
 
     Returns
     ----------
-        : float
-            Misak correlation score.
+        : np.float64
+            Misiak correlation score.
     '''
     G = np.empty((X.shape[1]+1, X.shape[1]+1))
     G[0, 0] = x @ y
@@ -343,7 +357,7 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
     result = result / np.sqrt(d)
     return result
 
-def trencevski_melceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
+def trencevski_malceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
     '''
     Generalized n-inner product correlation coefficient.
 
